==> nextcloud-13.0.1.tgz: nextcloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nevar rakstīt \"config\" mapē!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "To parasti var labot, dodot tīmekļa servera rakstīšanas piekļuvi config direktorijai",
    "See %s" : "Skatīt %s",
    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Datnes no programmas %$1s netika aizvietotas pareizi. Pārliecinieties, vai tā ir versija, kas ir saderīga ar serveri.",
    "Sample configuration detected" : "Atrasta konfigurācijas paraugs",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Konstatēts, ka paraug konfigurācija ir nokopēta. Tas var izjaukt jūsu instalāciju un nav atbalstīts. Lūdzu, izlasiet dokumentāciju, pirms veicat izmaiņas config.php",
    "%1$s and %2$s" : "%1$s un %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s un %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s un %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s un %5$s",
    "PHP %s or higher is required." : "Ir nepieciešams PHP %s vai jaunāks.",
    "PHP with a version lower than %s is required." : "Ir nepieciešams PHP vecāks kā %s.",
    "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
    "Following databases are supported: %s" : "Tiek atbalstītas šādas datu bāzes: %s",
    "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
    "The library %s is not available." : "Bibliotēka %s nav pieejama.",
    "Following platforms are supported: %s" : "Tiek atbalstītas šādas platformas: %s",
    "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
    "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "today" : "šodien",
    "yesterday" : "vakar",
    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
    "last month" : "pagājušajā mēnesī",
    "_%n month ago_::_%n months ago_" : ["%n mēneši atpakaļ","%n mēneši atpakaļ","%n mēnešiem"],
    "last year" : "gājušajā gadā",
    "_%n year ago_::_%n years ago_" : ["%n gadiem","%n gadiem","%n gadiem"],
    "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
    "seconds ago" : "sekundēm",
    "File name is too long" : "Faila nosaukums ir pārāk garš",
    "Empty filename is not allowed" : "Tukšs faila nosaukums nav atļauts",
    "Help" : "Palīdzība",
    "Apps" : "Programmas",
    "Users" : "Lietotāji",
    "Unknown user" : "Nezināms lietotājs",
    "APCu" : "APCu",
    "Sharing" : "Koplietošana",
    "Encryption" : "Šifrēšana",
    "Additional settings" : "Papildu iestatījumi",
    "Tips & tricks" : "Padomi un ieteikumi",
    "__language_name__" : "Latviešu",
    "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
    "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
    "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Oracle username and/or password not valid" : "Nav derīga Oracle parole un/vai lietotājvārds",
    "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
    "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
    "Set an admin password." : "Iestatiet administratora paroli.",
    "Invalid Federated Cloud ID" : "Nederīgs Federated Cloud ID",
    "%s shared »%s« with you" : "%s kopīgots »%s« ar jums",
    "%s via %s" : "%s ar %s",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "Su" : "Sv",
    "Mo" : "Pr",
    "Tu" : "Ot",
    "We" : "Tr",
    "Th" : "Ce",
    "Fr" : "Pi",
    "Sa" : "Se",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "The username is already being used" : "Šāds lietotājvārds jau tiek izmantots",
    "User disabled" : "Lietotājs deaktivizēts",
    "Login canceled by app" : "Pieteikšanās atcelta ar programmu",
    "a safe home for all your data" : "droša vieta visiem jūsu datiem",
    "File is currently busy, please try again later" : "Fails pašlaik ir aizņemts. lūdzu, vēlāk mēģiniet vēlreiz",
    "Can't read file" : "Nevar nolasīt failu",
    "Application is not enabled" : "Programma nav aktivēta",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
    "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
    "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
    "Please ask your server administrator to restart the web server." : "Lūdzu, palūdziet savam servera administratoram, restartēt Web serveri.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 nepieciešams",
    "Please upgrade your database version" : "Lūdzu, atjauniniet datu bāzes versiju",
    "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-15.0.5p1.tgz: nextcloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nevar rakstīt \"config\" mapē!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "To parasti var labot, dodot tīmekļa servera rakstīšanas piekļuvi config direktorijai",
    "See %s" : "Skatīt %s",
    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Datnes no programmas %$1s netika aizvietotas pareizi. Pārliecinieties, vai tā ir versija, kas ir saderīga ar serveri.",
    "Sample configuration detected" : "Atrasta konfigurācijas paraugs",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Konstatēts, ka paraug konfigurācija ir nokopēta. Tas var izjaukt jūsu instalāciju un nav atbalstīts. Lūdzu, izlasiet dokumentāciju, pirms veicat izmaiņas config.php",
    "%1$s and %2$s" : "%1$s un %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s un %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s un %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s un %5$s",
    "PHP %s or higher is required." : "Ir nepieciešams PHP %s vai jaunāks.",
    "PHP with a version lower than %s is required." : "Ir nepieciešams PHP vecāks kā %s.",
    "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
    "Following databases are supported: %s" : "Tiek atbalstītas šādas datu bāzes: %s",
    "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
    "The library %s is not available." : "Bibliotēka %s nav pieejama.",
    "Following platforms are supported: %s" : "Tiek atbalstītas šādas platformas: %s",
    "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
    "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "today" : "šodien",
    "yesterday" : "vakar",
    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
    "last month" : "pagājušajā mēnesī",
    "_%n month ago_::_%n months ago_" : ["%n mēneši atpakaļ","%n mēneši atpakaļ","%n mēnešiem"],
    "last year" : "gājušajā gadā",
    "_%n year ago_::_%n years ago_" : ["%n gadiem","%n gadiem","%n gadiem"],
    "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
    "seconds ago" : "sekundēm",
    "File name is too long" : "Faila nosaukums ir pārāk garš",
    "Empty filename is not allowed" : "Tukšs faila nosaukums nav atļauts",
    "__language_name__" : "Latviešu",
    "Help" : "Palīdzība",
    "Apps" : "Programmas",
    "Users" : "Lietotāji",
    "Unknown user" : "Nezināms lietotājs",
    "Sharing" : "Koplietošana",
    "Additional settings" : "Papildu iestatījumi",
    "%s enter the database username." : "%s ievadiet datubāzes lietotājvārdu.",
    "%s enter the database name." : "%s ievadiet datubāzes nosaukumu.",
    "%s you may not use dots in the database name" : "%s datubāžu nosaukumos nedrīkst izmantot punktus",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Oracle username and/or password not valid" : "Nav derīga Oracle parole un/vai lietotājvārds",
    "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
    "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
    "Set an admin password." : "Iestatiet administratora paroli.",
    "Invalid Federated Cloud ID" : "Nederīgs Federated Cloud ID",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "Su" : "Sv",
    "Mo" : "Pr",
    "Tu" : "Ot",
    "We" : "Tr",
    "Th" : "Ce",
    "Fr" : "Pi",
    "Sa" : "Se",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "The username is already being used" : "Šāds lietotājvārds jau tiek izmantots",
    "User disabled" : "Lietotājs deaktivizēts",
    "Login canceled by app" : "Pieteikšanos atcelā lietotne",
    "a safe home for all your data" : "droša vieta visiem jūsu datiem",
    "File is currently busy, please try again later" : "Datne pašlaik ir aizņemta. Lūdzu, vēlāk mēģiniet vēlreiz",
    "Can't read file" : "Nevar nolasīt failu",
    "Application is not enabled" : "Programma nav aktivēta",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
    "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
    "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
    "Please ask your server administrator to restart the web server." : "Lūdzu, palūdziet savam servera administratoram, restartēt Web serveri.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 nepieciešams",
    "Please upgrade your database version" : "Lūdzu, atjauniniet datu bāzes versiju",
    "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
    "APCu" : "APCu",
    "Encryption" : "Šifrēšana",
    "Tips & tricks" : "Padomi un ieteikumi",
    "%s shared »%s« with you" : "%s kopīgots »%s« ar jums",
    "%s via %s" : "%s ar %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
